==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/mi/mail.php <==
<?php

return array(
    'a_user_canceled' => 'Kua whakakorea e tetahi kaiwhakamahi tetahi tonoemi i runga i te paetukutuku',
    'a_user_requested' => 'Kua tono tetahi kaiwhakamahi i tetahi mea i runga i te paetukutuku',
    'accessory_name' => 'Ingoa Whakauru:',
    'additional_notes' => 'Nga Tuhipoka Atu:',
    'admin_has_created' => 'Kua hanga e tetahi kaiwhakahaere tetahi kaute mo koe i runga i te: paetukutuku tukutuku.',
    'asset' => 'Tahua:',
    'asset_name' => 'Ingoa Ahua:',
    'asset_requested' => 'Ka tonohia te taonga',
    'asset_tag' => 'Tae Tūemi:',
    'assigned_to' => 'Tohua Ki To',
    'best_regards' => 'Ko nga whakaaro pai,',
    'canceled' => 'Kua whakakorehia:',
    'checkin_date' => 'Rangi Whakatau:',
    'checkout_date' => 'Rā Whakatau:',
    'click_to_confirm' => 'Tena koahia te hono e whai ake nei hei whakauru i to:',
    'click_on_the_link_accessory' => 'Tena koahia te hono i raro ki te whakauru kua whiwhi koe i te taputapu.',
    'click_on_the_link_asset' => 'Koahia te hono i raro ki te whakauru kua riro ia koe te taonga.',
    'Confirm_Asset_Checkin' => 'Asset checkin confirmation',
    'Confirm_Accessory_Checkin' => 'Accessory checkin confirmation',
    'Confirm_accessory_delivery' => 'Accessory delivery confirmation',
    'Confirm_license_delivery' => 'License delivery confirmation',
    'Confirm_asset_delivery' => 'Asset delivery confirmation',
    'Confirm_consumable_delivery' => 'Consumable delivery confirmation',
    'current_QTY' => 'QTY o nāianei',
    'Days' => 'Nga ra',
    'days' => 'Nga ra',
    'expecting_checkin_date' => 'Te Whakataunga Whakataunga Whakaaro:',
    'expires' => 'Ka puta',
    'Expiring_Assets_Report' => 'Nga Putanga Taonga Taonga.',
    'Expiring_Licenses_Report' => 'Ripoata Raihana Whakamutunga.',
    'hello' => 'Hiha',
    'hi' => 'Hi',
    'i_have_read' => 'Kua korerohia e au, kua whakaae ki nga tikanga whakamahi, kua riro mai hoki tenei mea.',
    'item' => 'Te nama:',
    'Item_Request_Canceled' => 'Te Whakakore i te Tono',
    'Item_Requested' => 'Ko te nama i tonoa',
    'link_to_update_password' => 'Koahia te hono e whai ake nei hei whakahou i to: kupuhipahipa:',
    'login_first_admin' => 'Whakauru ki to taahiranga hou Snipe-IT ma te whakamahi i nga taipitopito kei raro nei:',
    'login' => 'Whakauru:',
    'Low_Inventory_Report' => 'Pūrongo Inventory Low',
    'min_QTY' => 'Min QTY',
    'name' => 'Ingoa',
    'new_item_checked' => 'Kua tohua tetahi mea hou i raro i to ingoa, kei raro iho nga korero.',
    'password' => 'Kupuhipa:',
    'password_reset' => 'Tautuhi Kupuhipa',

    'read_the_terms' => 'Tena koa korerotia nga tikanga o te whakamahi i raro.',
    'read_the_terms_and_click' => 'Tena koa panuihia nga tikanga whakamahi i raro nei, a ka pene i runga i te hono i raro ki te whakauru ka paahitia e koe me te whakaae ki nga tikanga o te whakamahinga, kua riro mai hoki te taonga.',
    'requested' => 'I tonohia:',
    'reset_link' => 'Tautuhi Hononga Kupuhipa',
    'reset_password' => 'Pāwhiri ki konei kia tautuhi i to kupuhipa:',
    'serial' => 'Serial',
    'supplier' => 'Kaihoko',
    'tag' => 'Tohu',
    'test_email' => 'Test Test from Snipe-IT',
    'test_mail_text' => 'He whakamatautau tenei mai i te Pūnaha Whakahaere Utu Snipe-IT. Mena kua whiwhi koe i tenei, kei te mahi te miihana :)',
    'the_following_item' => 'Kua tohua te mea e whai ake nei i:',
    'low_inventory_alert' => 'There is :count item that is below minimum inventory or will soon be low.|There are :count items that are below minimum inventory or will soon be low.',
    'assets_warrantee_alert' => 'There is :count asset with a warrantee expiring in the next :threshold days.|There are :count assets with warrantees expiring in the next :threshold days.',
    'license_expiring_alert' => 'There is :count license expiring in the next :threshold days.|There are :count licenses expiring in the next :threshold days.',
    'to_reset' => 'Hei tautuhi i to: kupuhipa tukutuku, whakaoti i tenei puka:',
    'type' => 'Momo',
    'upcoming-audits' => 'There is :count asset that is coming up for audit within :threshold days.|There are :count assets that are coming up for audit within :threshold days.',
    'user' => 'User',
    'username' => 'Username',
    'welcome' => 'Nau mai: ingoa',
    'welcome_to' => 'Nau mai ki: web!',
    'your_credentials' => 'Nga tohu tohu Snipe-IT',
    'Accessory_Checkin_Notification' => 'Accessory checked in',
    'Asset_Checkin_Notification' => 'Asset checked in',
    'License_Checkin_Notification' => 'License checked in',
    'Expected_Checkin_Report' => 'Expected asset checkin report',
    'Expected_Checkin_Notification' => 'Reminder: :name checkin deadline approaching',
    'Expected_Checkin_Date' => 'An asset checked out to you is due to be checked back in on :date',
    'your_assets' => 'View Your Assets'
);

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/mi/mail.php <==
<?php

return [
    'a_user_canceled' => 'Kua whakakorea e tetahi kaiwhakamahi tetahi tonoemi i runga i te paetukutuku',
    'a_user_requested' => 'Kua tono tetahi kaiwhakamahi i tetahi mea i runga i te paetukutuku',
    'accessory_name' => 'Ingoa Whakauru:',
    'additional_notes' => 'Nga Tuhipoka Atu:',
    'admin_has_created' => 'Kua hanga e tetahi kaiwhakahaere tetahi kaute mo koe i runga i te: paetukutuku tukutuku.',
    'asset' => 'Tahua:',
    'asset_name' => 'Ingoa Ahua:',
    'asset_requested' => 'Ka tonohia te taonga',
    'asset_tag' => 'Asset Tag',
    'assigned_to' => 'Tohua Ki To',
    'best_regards' => 'Ko nga whakaaro pai,',
    'canceled' => 'Kua whakakorehia:',
    'checkin_date' => 'Rangi Whakatau:',
    'checkout_date' => 'Rā Whakatau:',
    'click_to_confirm' => 'Tena koahia te hono e whai ake nei hei whakauru i to:',
    'click_on_the_link_accessory' => 'Tena koahia te hono i raro ki te whakauru kua whiwhi koe i te taputapu.',
    'click_on_the_link_asset' => 'Koahia te hono i raro ki te whakauru kua riro ia koe te taonga.',
    'Confirm_Asset_Checkin' => 'Asset checkin confirmation',
    'Confirm_Accessory_Checkin' => 'Accessory checkin confirmation',
    'Confirm_accessory_delivery' => 'Accessory delivery confirmation',
    'Confirm_license_delivery' => 'License delivery confirmation',
    'Confirm_asset_delivery' => 'Asset delivery confirmation',
    'Confirm_consumable_delivery' => 'Consumable delivery confirmation',
    'current_QTY' => 'QTY o nāianei',
    'Days' => 'Nga ra',
    'days' => 'Nga ra',
    'expecting_checkin_date' => 'Te Whakataunga Whakataunga Whakaaro:',
    'expires' => 'Ka puta',
    'Expiring_Assets_Report' => 'Nga Putanga Taonga Taonga.',
    'Expiring_Licenses_Report' => 'Ripoata Raihana Whakamutunga.',
    'hello' => 'Hiha',
    'hi' => 'Hi',
    'i_have_read' => 'Kua korerohia e au, kua whakaae ki nga tikanga whakamahi, kua riro mai hoki tenei mea.',
    'item' => 'Te nama:',
    'Item_Request_Canceled' => 'Te Whakakore i te Tono',
    'Item_Requested' => 'Ko te nama i tonoa',
    'link_to_update_password' => 'Koahia te hono e whai ake nei hei whakahou i to: kupuhipahipa:',
    'login_first_admin' => 'Whakauru ki to taahiranga hou Snipe-IT ma te whakamahi i nga taipitopito kei raro nei:',
    'login' => 'Whakauru:',
    'Low_Inventory_Report' => 'Pūrongo Inventory Low',
    'min_QTY' => 'Min QTY',
    'name' => 'Ingoa',
    'new_item_checked' => 'Kua tohua tetahi mea hou i raro i to ingoa, kei raro iho nga korero.',
    'password' => 'Kupuhipa:',
    'password_reset' => 'Tautuhi Kupuhipa',

    'read_the_terms' => 'Tena koa korerotia nga tikanga o te whakamahi i raro.',
    'read_the_terms_and_click' => 'Tena koa panuihia nga tikanga whakamahi i raro nei, a ka pene i runga i te hono i raro ki te whakauru ka paahitia e koe me te whakaae ki nga tikanga o te whakamahinga, kua riro mai hoki te taonga.',
    'requested' => 'I tonohia:',
    'reset_link' => 'Tautuhi Hononga Kupuhipa',
    'reset_password' => 'Pāwhiri ki konei kia tautuhi i to kupuhipa:',
    'serial' => 'Serial',
    'supplier' => 'Kaihoko',
    'tag' => 'Tohu',
    'test_email' => 'Test Test from Snipe-IT',
    'test_mail_text' => 'He whakamatautau tenei mai i te Pūnaha Whakahaere Utu Snipe-IT. Mena kua whiwhi koe i tenei, kei te mahi te miihana :)',
    'the_following_item' => 'Kua tohua te mea e whai ake nei i:',
    'low_inventory_alert' => 'There is :count item that is below minimum inventory or will soon be low.|There are :count items that are below minimum inventory or will soon be low.',
    'assets_warrantee_alert' => 'There is :count asset with a warranty expiring in the next :threshold days.|There are :count assets with warranties expiring in the next :threshold days.',
    'license_expiring_alert' => 'There is :count license expiring in the next :threshold days.|There are :count licenses expiring in the next :threshold days.',
    'to_reset' => 'Hei tautuhi i to: kupuhipa tukutuku, whakaoti i tenei puka:',
    'type' => 'Momo',
    'upcoming-audits' => 'There is :count asset that is coming up for audit within :threshold days.|There are :count assets that are coming up for audit within :threshold days.',
    'user' => 'User',
    'username' => 'Username',
    'welcome' => 'Nau mai: ingoa',
    'welcome_to' => 'Nau mai ki: web!',
    'your_credentials' => 'Nga tohu tohu Snipe-IT',
    'Accessory_Checkin_Notification' => 'Accessory checked in',
    'Asset_Checkin_Notification' => 'Asset checked in',
    'License_Checkin_Notification' => 'License checked in',
    'Expected_Checkin_Report' => 'Expected asset checkin report',
    'Expected_Checkin_Notification' => 'Reminder: :name checkin deadline approaching',
    'Expected_Checkin_Date' => 'An asset checked out to you is due to be checked back in on :date',
    'your_assets' => 'View Your Assets',
];
